package jdk.internal.jshell.tool.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "23" },
            { "jdk", "23" },
            { "release", "23" },
        };
    }
}
